summaryrefslogtreecommitdiffhomepage
path: root/src/nxt_string.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/nxt_string.c')
-rw-r--r--src/nxt_string.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/nxt_string.c b/src/nxt_string.c
index fb1cafd6..90e5734d 100644
--- a/src/nxt_string.c
+++ b/src/nxt_string.c
@@ -61,7 +61,7 @@ nxt_str_dup(nxt_mp_t *mp, nxt_str_t *dst, const nxt_str_t *src)
/*
* nxt_str_copy() creates a C style zero-terminated copy of a source
* nxt_str_t. The function is intended to create strings suitable
* for libc and kernel interfaces so result is pointer to char instead
* of u_char to minimize casts. The copy is aligned to 2 bytes thus
@@ -69,7 +69,7 @@ nxt_str_dup(nxt_mp_t *mp, nxt_str_t *dst, const nxt_str_t *src)
*/
char *
-nxt_str_copy(nxt_mp_t *mp, const nxt_str_t *src)
+nxt_str_cstrz(nxt_mp_t *mp, const nxt_str_t *src)
{
char *p, *dst;
@@ -61,7 +61,7 @@ nxt_str_dup(nxt_mp_t *mp, nxt_str_t *dst, const nxt_str_t *src)
/*
- * nxt_str_copy() creates a C style zero-terminated copy of a source
+ * nxt_str_cstrz() creates a C style zero-terminated copy of a source
* nxt_str_t. The function is intended to create strings suitable
* for libc and kernel interfaces so result is pointer to char instead